data {
	int<lower=0> N; 				// number observations or data points
	real yield_z[N];				// response yield z scored
	int<lower=1> J;					// number of sites
	int<lower=1, upper=J> site[N];	// site id
}

parameters {
	vector[1] beta;					// fixed intercept
	vector[J] u;					// site intercepts
	real<lower=0> sigma_u;			// site sd	
	real<lower=0> sigma_e;			// residual sd

}

transformed parameters {

	vector[N] mu;
	
	for (i in 1:N) {

		mu[i] = u[site[i]];

	}
}

model {
	
	// priors
	
	beta[1] ~ normal(0, 10);								// intercept (grand mean?)
	sigma_u ~ gamma(1, 0.1);								// site sd
	sigma_e ~ gamma(1, 0.1);								// residual sd
	u ~ normal(beta[1], sigma_u);							// site random effects
	
	// likelihood
	
	for (i in 1:N) {

		yield_z[i] ~ normal(mu[i], sigma_e);
	}			
}


generated quantities {
	vector[N] log_lik;

	for (i in 1:N) {
		log_lik[i] = normal_lpdf(yield_z[i] | mu[i], sigma_e);
	}
}




