data {
	int<lower=0> N; 				// number observations or data points
	real yield_z[N];				// response yield z scored
	real all_insects_z[N];			// predictor insect visits z scored
}

parameters {
	vector[2] beta;					// fixed intercept, slope
	real<lower=0> sigma_e;			// residual sd

}

transformed parameters {

	vector[N] mu;
	
	for (i in 1:N) {
		mu[i] = beta[1] + beta[2]*all_insects_z[i];
	}
}

model {
	
	// priors
	
	beta[1] ~ normal(0, 10);								// intercept (grand mean?)
	beta[2] ~ normal(0, 10);								// slope of all_insects_z
	sigma_e ~ gamma(1, 0.1);								// residual sd
	
	// likelihood
	
	for (i in 1:N) {

		yield_z[i] ~ normal(mu[i], sigma_e);
	}			
}


generated quantities {
	vector[N] log_lik;

	for (i in 1:N) {
		log_lik[i] = normal_lpdf(yield_z[i] | mu[i], sigma_e);
	}
}




